@@ -710,12 +710,12 @@ void WmWidget::slotRemoveMetaChecked()
 
 void WmWidget::slotChangeUserClicked()
 {
-    emit signalChangeUserRequest();
+    Q_EMIT signalChangeUserRequest();
 }
 
 void WmWidget::slotLoginClicked()
 {
-     emit signalLoginRequest(d->nameEdit->text(), d->passwdEdit->text(),
+     Q_EMIT signalLoginRequest(d->nameEdit->text(), d->passwdEdit->text(),
                              d->wikiSelect->itemText(d->wikiSelect->currentIndex()),
                              d->wikiSelect->itemData(d->wikiSelect->currentIndex()).toUrl());
 }
@@ -925,7 +925,7 @@ void WmWidget::slotApplyTitle()
         // If there is at least one #, replace it the correct number
         if (minLength > 0)
         {
-            parts      = imageTitle.split(QLatin1String("#"), QString::KeepEmptyParts);
+            parts      = imageTitle.split(QLatin1String("#"), Qt::KeepEmptyParts);
             imageTitle = parts.first().append(QLatin1String("#")).append(parts.last());
             number     = QString::number(i + 1);
 
